Learn R Programming

RtD3 (version 0.0.1)

getSubregionalUrls: Get Subregional Estimate Urls

Description

Get Subregional Estimate Urls

Usage

getSubregionalUrls(path, areas)

Arguments

path

A character string container the overall path to subnational estimates

areas

A character vector listing the subregional estimates (assuming that listed in the geoData with capitalisation and without capitalisation in the path).

Value

A named list of subnational urls.

Examples

Run this code
# NOT RUN {
getSubregionalUrls(path = "https://epiforecasts.io/covid/posts/national/",
                  areas = c('Afghanistan', 'Brazil', 'Colombia', 'United States'))

# }

Run the code above in your browser using DataLab