powered by
Get Subregional Estimate Urls
getSubregionalUrls(path, areas)
A character string container the overall path to subnational estimates
A character vector listing the subregional estimates (assuming that listed in the geoData with capitalisation and without capitalisation in the path).
A named list of subnational urls.
# NOT RUN { getSubregionalUrls(path = "https://epiforecasts.io/covid/posts/national/", areas = c('Afghanistan', 'Brazil', 'Colombia', 'United States')) # }
Run the code above in your browser using DataLab